pub struct ChimeraMiscAllocation { /* private fields */ }Available on crate feature
chimera only.Expand description
An allocation of memory using the chimera misc allocator.
The allocator used for this memory can be modified or accessed with
crate::alloc::chimera::set_chimera_misc_allocator() and
crate::alloc::chimera::get_chimera_misc_allocator() if the "alloc"
feature is enabled.
The backing memory will be deallocated by the chimera misc allocator
upon drop unless this is wrapped with a
ManuallyDrop.
Implementations