#[repr(transparent)]pub struct DbInfo(pub MiscAllocation);Expand description
Wrapper for allocated string data returned by Database::info().
Tuple Fields
0: MiscAllocationImplementations
Sourceimpl DbInfo
impl DbInfo
Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Return a view of the allocated string data.
Vectorscan will always return valid UTF-8 data for this string, so it skips the validity check. Note that the returned string does not include the trailing null byte allocated by the underlying vectorscan library.
Sourcepub fn extract_db_info(db: &Database) -> Result<Self, VectorscanRuntimeError>
pub fn extract_db_info(db: &Database) -> Result<Self, VectorscanRuntimeError>
Write out metadata for db into a newly allocated region.