pub struct Mode(/* private fields */);compiler only.Expand description
Compiler mode flags that affect the database as a whole.
No Default impl is provided, to enforce that at least one of
STREAM, BLOCK, or
VECTORED is supplied, to select between the generation
of a streaming, block or vectored database. In addition, other flags may be
supplied to enable or configure specific features such as stream state size.
Multiple flags may be used by ORing them together.
Implementations
Sourceimpl Mode
Basic Database Types
For now, each database can only be one of these types (this is checked by
vectorscan upon database creation).
impl Mode
Basic Database Types
For now, each database can only be one of these types (this is checked by vectorscan upon database creation).
Sourceimpl Mode
Stream State Precision Modes
These flags are currently only processed when Self::STREAM is requested.
impl Mode
Stream State Precision Modes
These flags are currently only processed when Self::STREAM is requested.
Sourcepub const SOM_HORIZON_LARGE: Self
Available on crate feature stream only.
pub const SOM_HORIZON_LARGE: Self
stream only.Use full precision to track start of match offsets in stream state.
This mode will use the most stream state per pattern, but will always return an accurate start of match offset regardless of how far back in the past it was found.
One of the SOM_HORIZON_* modes must be selected to use the
Flags::SOM_LEFTMOST expression flag.
Sourcepub const SOM_HORIZON_MEDIUM: Self
Available on crate feature stream only.
pub const SOM_HORIZON_MEDIUM: Self
stream only.Use medium precision to track start of match offsets in stream state.
This mode will use less stream state than
Self::SOM_HORIZON_LARGE and will limit start of
match accuracy to offsets within 2^32 bytes of the end of match offset
reported.
One of the SOM_HORIZON_* modes must be selected to use the
Flags::SOM_LEFTMOST expression flag.
Sourcepub const SOM_HORIZON_SMALL: Self
Available on crate feature stream only.
pub const SOM_HORIZON_SMALL: Self
stream only.Use limited precision to track start of match offsets in stream state.
This mode will use less stream state than
Self::SOM_HORIZON_LARGE and will limit start of
match accuracy to offsets within 2^16 bytes of the end of match offset
reported.
One of the SOM_HORIZON_* modes must be selected to use the
Flags::SOM_LEFTMOST expression flag.